# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .workflow_expression_condition_model_input_expression import WorkflowExpressionConditionModelInputExpression


class WorkflowExpressionConditionModelInput(UncheckedBaseModel):
    label: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional human-readable label for the condition used throughout the UI.
    """

    expression: WorkflowExpressionConditionModelInputExpression = pydantic.Field()
    """
    Expression to evaluate.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(WorkflowExpressionConditionModelInput)



# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.procedure_draft_ref import ProcedureDraftRef
from ....types.procedure_version_ref import ProcedureVersionRef

BodyPatchesAnAgentSettingsV1ConvaiAgentsAgentIdPatchProcedureRefsItem = typing.Union[
    ProcedureVersionRef, ProcedureDraftRef
]
